==> katapult-trinity-3.5.13.2.tar.xz: katapult-trinity-3.5.13.2/katapult/common/katapultcatalog.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Joe Ferris                                      *
 *   jferris@optimistictech.com                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef KATAPULTCATALOG_H
#define KATAPULTCATALOG_H

#include <tqobject.h>
#include <tqstring.h>
#include <tqptrlist.h>

#include "match.h"

class TQWidget;
class KConfigBase;

/**
@author Joe Ferris
*/
class KatapultCatalog : public TQObject {
	Q_OBJECT
  TQ_OBJECT

public:
	KatapultCatalog();
	virtual ~KatapultCatalog();
	
	void setQuery(TQString);
	
	int status() const;
	Match bestMatch() const;
	
	virtual void initialize();
	virtual void readSettings(KConfigBase *);
	virtual void writeSettings(KConfigBase *);
	virtual TQWidget * configure();
	
protected:
	TQString query() const;
	
	void setStatus(int);
	void setBestMatch(Match);
	
	virtual void queryChanged();

private:
	TQString _query;
	int _status;
	Match _bestMatch;

};

#endif

==> katapult-trinity_14.0.5.orig.tar.xz: katapult-trinity-14.0.5/katapult/common/katapultcatalog.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Joe Ferris                                      *
 *   jferris@optimistictech.com                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef KATAPULTCATALOG_H
#define KATAPULTCATALOG_H

#include <tqobject.h>
#include <tqstring.h>
#include <tqptrlist.h>

#include "match.h"

class TQWidget;
class TDEConfigBase;

/**
@author Joe Ferris
*/
class KatapultCatalog : public TQObject {
	Q_OBJECT
  

public:
	KatapultCatalog();
	virtual ~KatapultCatalog();
	
	void setQuery(TQString);
	
	int status() const;
	Match bestMatch() const;
	
	virtual void initialize();
	virtual void readSettings(TDEConfigBase *);
	virtual void writeSettings(TDEConfigBase *);
	virtual TQWidget * configure();
	
protected:
	TQString query() const;
	
	void setStatus(int);
	void setBestMatch(Match);
	
	virtual void queryChanged();

private:
	TQString _query;
	int _status;
	Match _bestMatch;

};

#endif
